package org.openepics.names.rest.beans.element;

import java.io.Serializable;
import java.util.Objects;
import java.util.UUID;

import org.openepics.names.rest.beans.Type;

import io.swagger.v3.oas.annotations.media.Schema;

public class StructureElementCommandCreate implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = 7866856977382945426L;

    @Schema(description = "Type of the structure entry. Valid values - SYSTEMGROUP, SYSTEM, SUBSYSTEM, DISCIPLINE, DEVICEGROUP, DEVICETYPE.")
    private Type type;
    @Schema(description = "Identity (uuid) for the structure entry parent (if the structure entry has a parent).")
    private UUID parent;
    @Schema(description = "Name of the structure entry.")
    private String name;
    @Schema(description = "Mnemonic of the structure entry.")
    private String mnemonic;
    @Schema(description = "Description of the structure entry.")
    private String description;
    @Schema(description = "Comment of the structure entry command.")
    private String comment;

    /**
     * Public constructor.
     */
    public StructureElementCommandCreate() {
    }

    /**
     * Public constructor.
     *
     * @param type type
     * @param parent parent uuid
     * @param name name
     * @param mnemonic mnemonic
     * @param description description
     * @param comment comment
     */
    public StructureElementCommandCreate(
            Type type, UUID parent,
            String name, String mnemonic,
            String description, String comment) {
        super();
        this.type = type;
        this.parent = parent;
        this.name = name;
        this.mnemonic = mnemonic;
        this.description = description;
        this.comment = comment;
    }

    public Type getType() {
        return type;
    }
    public void setType(Type type) {
        this.type = type;
    }
    public UUID getParent() {
        return parent;
    }
    public void setParent(UUID parent) {
        this.parent = parent;
    }
    public String getName() {
        return name;
    }
    public void setName(String name) {
        this.name = name;
    }
    public String getMnemonic() {
        return mnemonic;
    }
    public void setMnemonic(String mnemonic) {
        this.mnemonic = mnemonic;
    }
    public String getDescription() {
        return description;
    }
    public void setDescription(String description) {
        this.description = description;
    }
    public String getComment() {
        return comment;
    }
    public void setComment(String comment) {
        this.comment = comment;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;

        return equals ((StructureElementCommandCreate) obj);
    }

    public boolean equals(StructureElementCommandCreate other) {
        if (other == null)
            return false;

        if (!super.equals(other)) {
            return false;
        }

        if (getType() == null) {
            if (other.getType() != null)
                return false;
        } else if (!getType().equals(other.getType()))
            return false;
        if (getParent() == null) {
            if (other.getParent() != null)
                return false;
        } else if (!getParent().equals(other.getParent()))
            return false;
        if (getName() == null) {
            if (other.getName() != null)
                return false;
        } else if (!getName().equals(other.getName()))
            return false;
        if (getMnemonic() == null) {
            if (other.getMnemonic() != null)
                return false;
        } else if (!getMnemonic().equals(other.getMnemonic()))
            return false;
        if (getDescription() == null) {
            if (other.getDescription() != null)
                return false;
        } else if (!getDescription().equals(other.getDescription()))
            return false;
        if (getComment() == null) {
            if (other.getComment() != null)
                return false;
        } else if (!getComment().equals(other.getComment()))
            return false;

        return true;
    }

    @Override
    public int hashCode() {
        return Objects.hash(
                getType(), getParent(), getName(), getMnemonic(), getDescription(), getComment());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        sb.append("\"type\": "                    + getType());
        sb.append(", \"parent\": "                + getParent());
        sb.append(", \"name\": "                  + getName());
        sb.append(", \"mnemonic\": "              + getMnemonic());
        sb.append(", \"description\": "           + getDescription());
        sb.append(", \"comment\": "               + getComment());
        sb.append("}");
        return sb.toString();
    }

}
